Validates index metadata, every indexed file, and global uniqueness of R chunk labels. This should be run before committing changes to a bank.
Examples
validate_question_bank(example_question_index())
Validates index metadata, every indexed file, and global uniqueness of R chunk labels. This should be run before committing changes to a bank.
validate_question_bank(example_question_index())